==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultSwatchChooserPanel__24SwatchPanel.h <==
// abstract class javax.swing.colorchooser.DefaultSwatchChooserPanel$SwatchPanel

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 3146b457beeae28 javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel

// header file dependencies
// @dep_header javax_swing_JPanel

#include "javax/swing/JPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel_H_
#define _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vmethods	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtable	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtype	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *);

// Virtual methods
extern struct _jc_java_awt_Color$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method$getColorForPosition$9e238dcc81583aa7(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *, jint, jint);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *);
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method$initializeColors$177c4c7d81450fda(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *);
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method_info$getColorForPosition$9e238dcc81583aa7;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method_info$initializeColors$177c4c7d81450fda;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vmethods {
	struct _jc_java_awt_Color$object	*(*getColorForPosition$9e238dcc81583aa7)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *, jint, jint);
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *);
	void	(*initializeColors$177c4c7d81450fda)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$refs {
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_nonrefs {
	jint	cellWidth;
	jint	cellHeight;
	jint	gap;
	jint	numRows;
	jint	numCols;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object {
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtype _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel_H_ */

==> jc-1.4.5.tar.gz: javax/swing/colorchooser/DefaultSwatchChooserPanel__24SwatchPanel.h <==
// abstract class javax.swing.colorchooser.DefaultSwatchChooserPanel$SwatchPanel

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 3146b457beeae28 javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel

// header file dependencies
// @dep_header javax_swing_JPanel

#include "javax/swing/JPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel_H_
#define _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vmethods	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtable	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtype	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Color$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method$getColorForPosition$9e238dcc81583aa7(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method$initializeColors$177c4c7d81450fda(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method_info$getColorForPosition$9e238dcc81583aa7;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method_info$initializeColors$177c4c7d81450fda;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vmethods {
	struct _jc_java_awt_Color$object	*(*getColorForPosition$9e238dcc81583aa7)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *) _JC_JCNI_ATTR;
	void	(*initializeColors$177c4c7d81450fda)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$refs {
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_nonrefs {
	jint	cellWidth;
	jint	cellHeight;
	jint	gap;
	jint	numRows;
	jint	numCols;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$object {
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vtype _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel_H_ */
